pub enum Sign {
Positive,
Negative,
}Expand description
An enum representing the sign of a number
A sign can be converted to or from a boolean value, assuming true is Negative.
Variants
Implementations
Sourceimpl Sign
impl Sign
Sourcepub const fn as_sign_str(self, sign_plus: bool) -> &'static str
pub const fn as_sign_str(self, sign_plus: bool) -> &'static str
Return the sign as a string slice for formatting.
Returns "-" for Negative, "+" for Positive when sign_plus
is true, or "" for Positive when sign_plus is false.
Examples
assert_eq!(Sign::Negative.as_sign_str(false), "-");
assert_eq!(Sign::Positive.as_sign_str(true), "+");
assert_eq!(Sign::Positive.as_sign_str(false), "");Trait Implementations
impl Copy for Sign
impl Eq for Sign
Sourceimpl MulAssign for Sign
impl MulAssign for Sign
Sourcefn mul_assign(&mut self, rhs: Sign)
fn mul_assign(&mut self, rhs: Sign)
Performs the
*= operation. Read moreSourceimpl MulAssign<Sign> for IBig
impl MulAssign<Sign> for IBig
Sourcefn mul_assign(&mut self, rhs: Sign)
fn mul_assign(&mut self, rhs: Sign)
Performs the
*= operation. Read moreSourceimpl Ord for Sign
impl Ord for Sign
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Sign
impl PartialOrd for Sign
impl StructuralPartialEq for Sign